@@ -26,7 +26,7 @@ $magic = get_magic_quotes_gpc();
 $magicrt = get_magic_quotes_runtime();
 $adminver = new AdminVer;
 $adminver->major = 3;
-$adminver->minor = 03;
+$adminver->minor = 04;
 $adminver->extra = "";
 $updatereq = 0;
 
@@ -508,6 +508,19 @@ function updatedb() {
     update303();
   }
 
+  $ver = currentver();
+  if ($ver == -1) {
+    $versioncheck = "Version check error!<br />\n";
+    menu_bottom();
+    exit;
+  }
+  list($vermajor, $verminor, $verextra) = $ver;
+  if ($vermajor == 3 && $verminor == 3) {
+    echo "Updating database to version 3.04....<br /><br />\n";
+    include_once("includes/adminupdate.php");
+    update304();
+  }
+
   menu_bottom();
   exit;
 }
