@@ -2,7 +2,7 @@
 
 /*
     UTStatsDB
-    Copyright (C) 2002-2006  Patrick Contreras / Paul Gallier
+    Copyright (C) 2002-2007  Patrick Contreras / Paul Gallier
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ function mainconfig() {
 
   echo <<<EOF
 <form action="admin.php" method="post">
-  <input type="hidden" name="SaveType" value="Main">
+  <input type="hidden" name="SaveType" value="Main" />
   <table class="forms">
     <tr>
       <th width="110">&nbsp;</th>
@@ -78,7 +78,7 @@ EOF;
     <tr>
       <td align="right" class="forms" title="$desc"><b>$name:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="$option" value="$value" size="$len" maxlength="$maxlen" class="forms">
+        <input type="text" name="$option" value="$value" size="$len" maxlength="$maxlen" class="forms" />
       </td>
     </tr>
 
@@ -91,7 +91,7 @@ EOF;
     <tr>
       <td align="right" class="forms" title="$desc"><b>$name:</b></td>
       <td align="left" class="forms">
-        <input type="password" name="$option" value="$value" size="$len" maxlength="$len" class="forms">
+        <input type="password" name="$option" value="$value" size="$len" maxlength="$len" class="forms" />
       </td>
     </tr>
 
@@ -109,10 +109,10 @@ EOF;
 
         for ($i = 0; $i < $len; $i++) {
           if ($i == $value)
-            $setcheck = "checked";
+            $setcheck = "checked=\"checked\"";
           else
             $setcheck = "";
-          echo "<input type=\"radio\" name=\"$option\" value=\"$i\" $setcheck>{$buttons[$i]}\n";
+          echo "<input type=\"radio\" name=\"$option\" value=\"$i\" $setcheck />{$buttons[$i]}\n";
         }
 
         echo <<<EOF
@@ -153,7 +153,7 @@ EOF;
       <td colspan="2" class="forms">
       	<br />
       	&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-        <input type="submit" name="Mode" value="Save" class="formsb">
+        <input type="submit" name="Mode" value="Save" class="formsb" />
         &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Mouse over text for full description.
       </td>
     </tr>
@@ -175,7 +175,7 @@ function logsconfig() {
 
   echo <<<EOF
 <form action="admin.php" method="post">
-  <input type="hidden" name="SaveType" value="Logs">
+  <input type="hidden" name="SaveType" value="Logs" />
   <table class="forms">
     <tr>
       <th width="85">&nbsp;</th>
@@ -186,7 +186,7 @@ function logsconfig() {
 
 EOF;
 
-  $result = sql_query("SELECT num,logpath,backuppath,prefix,noport,ftpserver,ftppath,passive,alllogs,ftpuser,ftppass,deftype,defteam,demoftppath,multicheck FROM {$dbpre}configlogs ORDER BY num");
+  $result = sql_query("SELECT num,logpath,backuppath,prefix,chatprefix,chatrequire,noport,ftpserver,ftppath,passive,alllogs,ftpuser,ftppass,deftype,defteam,demoftppath,multicheck FROM {$dbpre}configlogs ORDER BY num");
   if (!$result) {
   	echo "Config database error!<br />\n";
     exit;
@@ -199,28 +199,32 @@ EOF;
     $logpath = $magicrt ? stripslashes($row[1]) : $row[1];
     $backuppath = $magicrt ? stripslashes($row[2]) : $row[2];
     $prefix = $magicrt ? stripslashes($row[3]) : $row[3];
-    $noport = intval($row[4]);
-    $ftpserver = $magicrt ? stripslashes($row[5]) : $row[5];
-    $ftppath = $magicrt ? stripslashes($row[6]) : $row[6];
-    $passive = intval($row[7]);
-    $alllogs = intval($row[8]);
-    $ftpuser = $magicrt ? stripslashes($row[9]) : $row[9];
-    $ftppass = $magicrt ? stripslashes($row[10]) : $row[10];
-    $deftype = intval($row[11]);
-    $defteam = intval($row[12]);
-    $demoftppath = $magicrt ? stripslashes($row[13]) : $row[13];
-    $multicheck = intval($row[14]);
+    $chatprefix = $magicrt ? stripslashes($row[4]) : $row[4];
+	$chatreq = intval($row[5]);
+    $noport = intval($row[6]);
+    $ftpserver = $magicrt ? stripslashes($row[7]) : $row[7];
+    $ftppath = $magicrt ? stripslashes($row[8]) : $row[8];
+    $passive = intval($row[9]);
+    $alllogs = intval($row[10]);
+    $ftpuser = $magicrt ? stripslashes($row[11]) : $row[11];
+    $ftppass = $magicrt ? stripslashes($row[12]) : $row[12];
+    $deftype = intval($row[13]);
+    $defteam = intval($row[14]);
+    $demoftppath = $magicrt ? stripslashes($row[15]) : $row[15];
+    $multicheck = intval($row[16]);
 
-    $noportx0 = $noport ? "" : "checked";
-    $noportx1 = $noport ? "checked" : "";
-    $passivex0 = $passive ? "" : "checked";
-    $passivex1 = $passive ? "checked" : "";
-    $alllogsx0 = $alllogs ? "" : "checked";
-    $alllogsx1 = $alllogs ? "checked" : "";
-    $defteamx0 = $defteam ? "" : "checked";
-    $defteamx1 = $defteam ? "checked" : "";
-    $multicheckx0 = $multicheck ? "" : "checked";
-    $multicheckx1 = $multicheck ? "checked" : "";
+    $chatreqx0 = $chatreq ? "" : "checked=\"checked\"";
+    $chatreqx1 = $chatreq ? "checked=\"checked\"" : "";
+    $noportx0 = $noport ? "" : "checked=\"checked\"";
+    $noportx1 = $noport ? "checked=\"checked\"" : "";
+    $passivex0 = $passive ? "" : "checked=\"checked\"";
+    $passivex1 = $passive ? "checked=\"checked\"" : "";
+    $alllogsx0 = $alllogs ? "" : "checked=\"checked\"";
+    $alllogsx1 = $alllogs ? "checked=\"checked\"" : "";
+    $defteamx0 = $defteam ? "" : "checked=\"checked\"";
+    $defteamx1 = $defteam ? "checked=\"checked\"" : "";
+    $multicheckx0 = $multicheck ? "" : "checked=\"checked\"";
+    $multicheckx1 = $multicheck ? "checked=\"checked\"" : "";
 
     if ($logsets > 1)
       echo <<<EOF
@@ -234,78 +238,89 @@ EOF;
     <tr>
       <td align="right" class="forms" title="Path to where log files are stored or downloaded to on stats server (relative or absolute)."><b>Log Path:</b></td>
       <td align="left" colspan="3" class="forms">
-        <input type="text" name="logpath{$num}" value="$logpath" size="120" maxlength="200" class="forms">
+        <input type="text" name="logpath{$num}" value="$logpath" size="120" maxlength="200" class="forms" />
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="Path to where log files are backed up after successfully parsing.  Leave blank to not backup."><b>Backup Path:</b></td>
       <td align="left" colspan="3" class="forms">
-        <input type="text" name="backuppath{$num}" value="$backuppath" size="120" maxlength="200" class="forms">
+        <input type="text" name="backuppath{$num}" value="$backuppath" size="120" maxlength="200" class="forms" />
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="Prefix of log files, before the timestamp or port number."><b>Log Prefix:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="prefix{$num}" value="$prefix" size="80" maxlength="60" class="forms">
+        <input type="text" name="prefix{$num}" value="$prefix" size="80" maxlength="60" class="forms" />
       </td>
       <td align="right" class="forms" title="Set true if the log filenames do not contain the server port number."><b>No Port:</b></td>
       <td align="left" class="forms">
-        <input type="radio" name="noport{$num}" value="0" $noportx0>False
-        <input type="radio" name="noport{$num}" value="1" $noportx1>True
+        <input type="radio" name="noport{$num}" value="0" $noportx0 />False
+        <input type="radio" name="noport{$num}" value="1" $noportx1 />True
+      </td>
+    </tr>
+    <tr>
+      <td align="right" class="forms" title="Prefix of chat log files, before the timestamp or port number."><b>Chat Prefix:</b></td>
+      <td align="left" class="forms">
+        <input type="text" name="chatprefix{$num}" value="$chatprefix" size="80" maxlength="60" class="forms" />
+      </td>
+      <td align="right" class="forms" title="Set true if only logs with matching chat logs should be processed."><b>Require Chat:</b></td>
+      <td align="left" class="forms">
+        <input type="radio" name="chatreq{$num}" value="0" $chatreqx0 />False
+        <input type="radio" name="chatreq{$num}" value="1" $chatreqx1 />True
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="FTP server address, including ftp:// or ftps// and port number (:21 default)."><b>FTP Server:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="ftpserver{$num}" value="$ftpserver" size="80" maxlength="100" class="forms">
+        <input type="text" name="ftpserver{$num}" value="$ftpserver" size="80" maxlength="100" class="forms" />
       </td>
       <td align="right" class="forms" title="Set true to use FTP passive mode, false for active mode."><b>Passive Mode:</b></td>
       <td align="left" class="forms">
-        <input type="radio" name="passive{$num}" value="0" $passivex0>False
-        <input type="radio" name="passive{$num}" value="1" $passivex1>True
+        <input type="radio" name="passive{$num}" value="0" $passivex0 />False
+        <input type="radio" name="passive{$num}" value="1" $passivex1 />True
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="FTP server username."><b>FTP User:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="ftpuser{$num}" value="$ftpuser" size="80" maxlength="30" class="forms">
+        <input type="text" name="ftpuser{$num}" value="$ftpuser" size="80" maxlength="30" class="forms" />
       </td>
       <td align="right" class="forms" title="Set to default game type (0=Other,1=DM,2=CTF,3=BR,4=TDM,5=AS,6=ONS,7=DD,8=MU,9=INV,10=LMS)."><b>Default Type:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="deftype{$num}" value="$deftype" size="4" maxlength="2" class="forms">
+        <input type="text" name="deftype{$num}" value="$deftype" size="4" maxlength="2" class="forms" />
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="FTP server password."><b>FTP Password:</b></td>
       <td align="left" class="forms">
-        <input type="password" name="ftppass{$num}" value="$ftppass" size="80" maxlength="30" class="forms">
+        <input type="password" name="ftppass{$num}" value="$ftppass" size="80" maxlength="30" class="forms" />
       </td>
       <td align="right" class="forms" title="Set true to have new game types default as team games."><b>Team Game:</b></td>
       <td align="left" class="forms">
-        <input type="radio" name="defteam{$num}" value="0" $defteamx0>False
-        <input type="radio" name="defteam{$num}" value="1" $defteamx1>True
+        <input type="radio" name="defteam{$num}" value="0" $defteamx0 />False
+        <input type="radio" name="defteam{$num}" value="1" $defteamx1 />True
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="Path to logs on FTP server - relative to path at login."><b>FTP Path:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="ftppath{$num}" value="$ftppath" size="80" maxlength="200" class="forms">
+        <input type="text" name="ftppath{$num}" value="$ftppath" size="80" maxlength="200" class="forms" />
       </td>
       <td align="right" class="forms" title="Set false to leave the most recent log on the server."><b>All Logs:</b></td>
       <td align="left" class="forms">
-        <input type="radio" name="alllogs{$num}" value="0" $alllogsx0>False
-        <input type="radio" name="alllogs{$num}" value="1" $alllogsx1>True
+        <input type="radio" name="alllogs{$num}" value="0" $alllogsx0 />False
+        <input type="radio" name="alllogs{$num}" value="1" $alllogsx1 />True
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="Path to demorec logs on FTP server - relative to path at login."><b>Demorec Path:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="demoftppath{$num}" value="$demoftppath" size="80" maxlength="200" class="forms">
+        <input type="text" name="demoftppath{$num}" value="$demoftppath" size="80" maxlength="200" class="forms" />
       </td>
       <td align="right" class="forms" title="Set true for UTStatsDB to handle calculating multi-kills."><b>Multi-check:</b></td>
       <td align="left" class="forms">
-        <input type="radio" name="multicheck{$num}" value="0" $multicheckx0>False
-        <input type="radio" name="multicheck{$num}" value="1" $multicheckx1>True
+        <input type="radio" name="multicheck{$num}" value="0" $multicheckx0 />False
+        <input type="radio" name="multicheck{$num}" value="1" $multicheckx1 />True
       </td>
     </tr>
 
@@ -318,9 +333,9 @@ EOF;
       <td colspan="4">
       	<br />
       	&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-        <input type="submit" name="Mode" value="Save" class="formsb">
+        <input type="submit" name="Mode" value="Save" class="formsb" />
         &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-        <input type="submit" name="Mode" value="Add" class="formsb">
+        <input type="submit" name="Mode" value="Add" class="formsb" />
         &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;To delete a record: clear the log path field and save. Mouse-over headings for full descriptions.
       </td>
     </tr>
@@ -342,7 +357,7 @@ function queryconfig() {
 
   echo <<<EOF
 <form action="admin.php" method="post">
-  <input type="hidden" name="SaveType" value="Query">
+  <input type="hidden" name="SaveType" value="Query" />
   <table class="forms">
     <tr>
       <th width="5">&nbsp;</th>
@@ -373,12 +388,12 @@ EOF;
     $spectators = intval($row[6]);
     $bots = intval($row[7]);
 
-    $typex = array("", "", "");
-    $typex[$type] = "checked";
-    $spectatorsx0 = $spectators ? "" : "checked";
-    $spectatorsx1 = $spectators ? "checked" : "";
-    $botsx0 = $bots ? "" : "checked";
-    $botsx1 = $bots ? "checked" : "";
+    $typex = array("", "", "", "");
+    $typex[$type] = "checked=\"checked\"";
+    $spectatorsx0 = $spectators ? "" : "checked=\"checked\"";
+    $spectatorsx1 = $spectators ? "checked=\"checked\"" : "";
+    $botsx0 = $bots ? "" : "checked=\"checked\"";
+    $botsx1 = $bots ? "checked=\"checked\"" : "";
 
     if ($queryset > 1)
       echo <<<EOF
@@ -391,18 +406,18 @@ EOF;
     echo "    <tr>\n";
 
     if ($queryset > 1)
-      echo "      <td align=\"left\" class=\"forms\" title=\"Move server up on list\"><input type=\"image\" name=\"QueryUp\" value=\"$queryset\" class=\"formsb\" src=\"resource/move_up.gif\"></td>\n";
+      echo "      <td align=\"left\" class=\"forms\" title=\"Move server up on list\"><input type=\"image\" name=\"QueryUp\" value=\"$queryset\" class=\"formsb\" src=\"resource/move_up.gif\" /></td>\n";
     else
       echo "      <td align=\"left\" class=\"forms\">&nbsp;</td>\n";
 
     echo <<<EOF
       <td align="right" class="forms" title="Server address (domain or IP) to query (excluding port)."><b>Query Server:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="server{$num}" value="$server" size="60" maxlength="200" class="forms">
+        <input type="text" name="server{$num}" value="$server" size="60" maxlength="200" class="forms" />
       </td>
       <td align="right" class="forms" title="Query password for playerhashes query (ServerExt)."><b>Password:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="password{$num}" value="$password" size="25" maxlength="40" class="forms">
+        <input type="text" name="password{$num}" value="$password" size="25" maxlength="40" class="forms" />
       </td>
     </tr>
     <tr>
@@ -410,38 +425,39 @@ EOF;
 EOF;
 
     if ($queryset < $numrows)
-      echo "      <td align=\"left\" class=\"forms\" title=\"Move server down on list\"><input type=\"image\" name=\"QueryDown\" value=\"$queryset\" class=\"formsb\" src=\"resource/move_down.gif\"></td>\n";
+      echo "      <td align=\"left\" class=\"forms\" title=\"Move server down on list\"><input type=\"image\" name=\"QueryDown\" value=\"$queryset\" class=\"formsb\" src=\"resource/move_down.gif\" /></td>\n";
     else
       echo "      <td align=\"left\" class=\"forms\">&nbsp;</td>\n";
 
     echo <<<EOF
       <td align="right" class="forms" title="Port number of server (game port)."><b>Game Port:</b></td>
       <td align="left" class="forms">
-        <input type="text" name="port{$num}" value="$port" size="60" maxlength="60" class="forms">
+        <input type="text" name="port{$num}" value="$port" size="60" maxlength="60" class="forms" />
       </td>
-      <td align="right" class="forms" title="Query type (GameSpy or UT). Use UT style query if possible."><b>Query Type:</b></td>
+      <td align="right" class="forms" title="Query type (UT, GameSpy, UT'99, or UT3)."><b>Query Type:</b></td>
       <td align="left" class="forms">
-    <input type="radio" name="type{$num}" value="0" {$typex[0]}>Unreal
-    <input type="radio" name="type{$num}" value="1" {$typex[1]}>Game Spy
-    <input type="radio" name="type{$num}" value="2" {$typex[2]}>UT 99
+        <input type="radio" name="type{$num}" value="0" {$typex[0]} />Unreal
+        <input type="radio" name="type{$num}" value="1" {$typex[1]} />Game Spy
+        <input type="radio" name="type{$num}" value="2" {$typex[2]} />UT 99
+        <input type="radio" name="type{$num}" value="3" {$typex[3]} />UT3
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="Full URL to game server." colspan="2"><b>Server Link:</b></td>
       <td align="left" colspan="3" class="forms">
-        <input type="text" name="link{$num}" value="$link" size="120" maxlength="200" class="forms">
+        <input type="text" name="link{$num}" value="$link" size="120" maxlength="200" class="forms" />
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="Include spectators in server query status." colspan="2"><b>Spectators:</b></td>
       <td align="left" class="forms">
-        <input type="radio" name="spectators{$num}" value="0" $spectatorsx0>Disable
-        <input type="radio" name="spectators{$num}" value="1" $spectatorsx1>Enable
+        <input type="radio" name="spectators{$num}" value="0" $spectatorsx0 />Disable
+        <input type="radio" name="spectators{$num}" value="1" $spectatorsx1 />Enable
       </td>
       <td align="right" class="forms" title="Include bots in server query status."><b>Bots:</b></td>
       <td align="left" class="forms">
-        <input type="radio" name="bots{$num}" value="0" $botsx0>Disable
-        <input type="radio" name="bots{$num}" value="1" $botsx1>Enable
+        <input type="radio" name="bots{$num}" value="0" $botsx0 />Disable
+        <input type="radio" name="bots{$num}" value="1" $botsx1 />Enable
       </td>
     </tr>
 
@@ -459,8 +475,8 @@ EOF;
       <td colspan="4">
         <table cellspacing="0" cellpadding="10">
           <tr>
-            <td><input type="submit" name="Mode" value="Save" class="formsb"></td>
-            <td><input type="submit" name="Mode" value="Add" class="formsb"></td>
+            <td><input type="submit" name="Mode" value="Save" class="formsb" /></td>
+            <td><input type="submit" name="Mode" value="Add" class="formsb" /></td>
             <td>{$qstxt}</td>
           </tr>
         </table>
@@ -484,7 +500,7 @@ function menuconfig() {
 
   echo <<<EOF
 <form action="admin.php" method="post">
-  <input type="hidden" name="SaveType" value="Menu">
+  <input type="hidden" name="SaveType" value="Menu" />
   <table class="forms">
     <tr>
       <th width="60">&nbsp;</th>
@@ -522,13 +538,13 @@ EOF;
     <tr>
       <td align="right" class="forms" title="Full or relative URL."><b>URL:</b></td>
       <td align="left" colspan="3" class="forms">
-        <input type="text" name="url{$num}" value="$urls" size="120" maxlength="200" class="forms">
+        <input type="text" name="url{$num}" value="$urls" size="120" maxlength="200" class="forms" />
       </td>
     </tr>
     <tr>
       <td align="right" class="forms" title="Description to display on menu."><b>Description:</b></td>
       <td align="left" colspan="3" class="forms">
-        <input type="text" name="descr{$num}" value="$descrs" size="120" maxlength="200" class="forms">
+        <input type="text" name="descr{$num}" value="$descrs" size="120" maxlength="200" class="forms" />
       </td>
     </tr>
 
@@ -541,9 +557,9 @@ EOF;
       <td colspan="4">
       	<br />
       	&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-        <input type="submit" name="Mode" value="Save" class="formsb">
+        <input type="submit" name="Mode" value="Save" class="formsb" />
         &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
-        <input type="submit" name="Mode" value="Add" class="formsb">
+        <input type="submit" name="Mode" value="Add" class="formsb" />
         &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;To delete a record: clear the URL field and save.
       </td>
     </tr>
@@ -631,7 +647,7 @@ function saveconfig() {
     }
     case "Logs":
     {
-      $resultb = sql_querynb($link, "SELECT num,logpath,backuppath,prefix,noport,ftpserver,ftppath,passive,alllogs,ftpuser,ftppass,deftype,defteam,demoftppath,multicheck FROM {$dbpre}configlogs ORDER BY num");
+      $resultb = sql_querynb($link, "SELECT num,logpath,backuppath,prefix,chatprefix,chatrequire,noport,ftpserver,ftppath,passive,alllogs,ftpuser,ftppass,deftype,defteam,demoftppath,multicheck FROM {$dbpre}configlogs ORDER BY num");
       if (!$resultb) {
   	    echo "Config database error!<br />\n";
   	    sql_close($link);
@@ -643,27 +659,32 @@ function saveconfig() {
         $logpath = $magicrt ? stripslashes($row[1]) : $row[1];
         $backuppath = $magicrt ? stripslashes($row[2]) : $row[2];
         $prefix = $magicrt ? stripslashes($row[3]) : $row[3];
-        $noport = intval($row[4]);
-        $ftpserver = $magicrt ? stripslashes($row[5]) : $row[5];
-        $ftppath = $magicrt ? stripslashes($row[6]) : $row[6];
-        $passive = intval($row[7]);
-        $alllogs = intval($row[8]);
-        $ftpuser = $magicrt ? stripslashes($row[9]) : $row[9];
-        $ftppass = $magicrt ? stripslashes($row[10]) : $row[10];
-        $deftype = intval($row[11]);
-        $defteam = intval($row[12]);
-        $demoftppath = $magicrt ? stripslashes($row[13]) : $row[13];
-        $multicheck = intval($row[14]);
+        $chatprefix = $magicrt ? stripslashes($row[4]) : $row[4];
+        $chatreq = intval($row[5]);
+        $noport = intval($row[6]);
+        $ftpserver = $magicrt ? stripslashes($row[7]) : $row[7];
+        $ftppath = $magicrt ? stripslashes($row[8]) : $row[8];
+        $passive = intval($row[9]);
+        $alllogs = intval($row[10]);
+        $ftpuser = $magicrt ? stripslashes($row[11]) : $row[11];
+        $ftppass = $magicrt ? stripslashes($row[12]) : $row[12];
+        $deftype = intval($row[13]);
+        $defteam = intval($row[14]);
+        $demoftppath = $magicrt ? stripslashes($row[15]) : $row[15];
+        $multicheck = intval($row[16]);
 
         if (isset($_POST["logpath{$num}"]) && isset($_POST["backuppath{$num}"]) && isset($_POST["prefix{$num}"]) &&
-            isset($_POST["noport{$num}"]) && isset($_POST["ftpserver{$num}"]) && isset($_POST["ftppath{$num}"]) &&
-            isset($_POST["ftppath{$num}"]) && isset($_POST["passive{$num}"]) && isset($_POST["alllogs{$num}"]) &&
-            isset($_POST["ftpuser{$num}"]) && isset($_POST["ftppass{$num}"]) && isset($_POST["deftype{$num}"]) &&
-            isset($_POST["defteam{$num}"]) && isset($_POST["demoftppath{$num}"]) && isset($_POST["multicheck{$num}"]))
+            isset($_POST["chatprefix{$num}"]) && isset($_POST["chatreq{$num}"]) && isset($_POST["noport{$num}"]) &&
+            isset($_POST["ftpserver{$num}"]) && isset($_POST["ftppath{$num}"]) && isset($_POST["ftppath{$num}"]) &&
+            isset($_POST["passive{$num}"]) && isset($_POST["alllogs{$num}"]) && isset($_POST["ftpuser{$num}"]) &&
+            isset($_POST["ftppass{$num}"]) && isset($_POST["deftype{$num}"]) && isset($_POST["defteam{$num}"]) &&
+            isset($_POST["demoftppath{$num}"]) && isset($_POST["multicheck{$num}"]))
         {
           $newlogpath = $magic ? stripslashes($_POST["logpath{$num}"]) : $_POST["logpath{$num}"];
           $newbackuppath = $magic ? stripslashes($_POST["backuppath{$num}"]) : $_POST["backuppath{$num}"];
           $newprefix = $magic ? stripslashes($_POST["prefix{$num}"]) : $_POST["prefix{$num}"];
+          $newchatprefix = $magic ? stripslashes($_POST["chatprefix{$num}"]) : $_POST["chatprefix{$num}"];
+          $newchatreq = intval($_POST["chatreq{$num}"]);
           $newnoport = intval($_POST["noport{$num}"]);
           $newftpserver = $magic ? stripslashes($_POST["ftpserver{$num}"]) : $_POST["ftpserver{$num}"];
           $newftppath = $magic ? stripslashes($_POST["ftppath{$num}"]) : $_POST["ftppath{$num}"];
@@ -676,14 +697,15 @@ function saveconfig() {
           $newdemoftppath = $magic ? stripslashes($_POST["demoftppath{$num}"]) : $_POST["demoftppath{$num}"];
           $newmulticheck = intval($_POST["multicheck{$num}"]);
 
-          if ($logpath != $newlogpath || $backuppath != $newbackuppath || $prefix != $newprefix || $noport != $newnoport ||
-              $ftpserver != $newftpserver || $ftppath != $newftppath || $passive != $newpassive || $alllogs != $newalllogs ||
-              $ftpuser != $newftpuser || $ftppass != $newftppass || $deftype != $newdeftype || $defteam != $newdefteam ||
-              $demoftppath != $newdemoftppath || $multicheck != $newmulticheck)
+          if ($logpath != $newlogpath || $backuppath != $newbackuppath || $prefix != $newprefix || $chatprefix != $newchatprefix ||
+              $chatreq != $newchatreq || $noport != $newnoport || $ftpserver != $newftpserver || $ftppath != $newftppath ||
+              $passive != $newpassive || $alllogs != $newalllogs || $ftpuser != $newftpuser || $ftppass != $newftppass ||
+              $deftype != $newdeftype || $defteam != $newdefteam || $demoftppath != $newdemoftppath || $multicheck != $newmulticheck)
           {
             $newlogpath = addslashes($newlogpath);
             $newbackuppath = addslashes($newbackuppath);
             $newprefix = addslashes($newprefix);
+            $newchatprefix = addslashes($newchatprefix);
             $newftpserver = addslashes($newftpserver);
             $newftppath = addslashes($newftppath);
             $newftpuser = addslashes($newftpuser);
@@ -692,7 +714,7 @@ function saveconfig() {
             if ($newlogpath == "")
               sql_queryn($link, "DELETE FROM {$dbpre}configlogs WHERE num=$num");
             else
-              sql_queryn($link, "UPDATE {$dbpre}configlogs SET logpath='$newlogpath',backuppath='$newbackuppath',prefix='$newprefix',noport=$newnoport,ftpserver='$newftpserver',ftppath='$newftppath',passive=$newpassive,alllogs=$newalllogs,ftpuser='$newftpuser',ftppass='$newftppass',deftype=$newdeftype,defteam=$newdefteam,demoftppath='$newdemoftppath',multicheck=$newmulticheck WHERE num=$num");
+              sql_queryn($link, "UPDATE {$dbpre}configlogs SET logpath='$newlogpath',backuppath='$newbackuppath',prefix='$newprefix',chatprefix='$newchatprefix',chatrequire=$newchatreq,noport=$newnoport,ftpserver='$newftpserver',ftppath='$newftppath',passive=$newpassive,alllogs=$newalllogs,ftpuser='$newftpuser',ftppass='$newftppass',deftype=$newdeftype,defteam=$newdefteam,demoftppath='$newdemoftppath',multicheck=$newmulticheck WHERE num=$num");
           }
         }
       }
