@@ -19,6 +19,122 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+function update304()
+{
+  global $dbtype, $dbpre, $break;
+
+  $link = sql_connect();
+
+  echo "Updating {$dbpre}weapons...<br />\n";
+  if (strtolower($dbtype) == "mysql")
+  {
+    $result = sql_queryn($link, "ALTER TABLE {$dbpre}weapons MODIFY wp_type varchar(60) NOT NULL default '', MODIFY wp_desc varchar(40) NOT NULL default ''");
+    if (!$result) {
+      echo "<br />Error updating weapons table.{$break}\n";
+      exit;
+    }
+  }
+
+  echo "Updating weapon descriptions....<br />\n";
+  $fname = "tables/".strtolower($dbtype)."/weapons.sql";
+  if (file_exists($fname)) {
+    $sqldata = file($fname);
+
+    while($row = each($sqldata)) {
+      $line = trim($row[1], "\t\n\r\0;");
+      $line = str_replace("\n", "", $line);
+
+      $ltype = 0;
+      if (strlen($line) > 59 && substr($line, 0, 1) != "#" && strstr($line, "INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES(") != FALSE)
+        $ltype = 1;
+      else if (strlen($line) > 73 && substr($line, 0, 1) != "#" && strstr($line, "INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES(") != FALSE)
+        $ltype = 2;
+      else if (strlen($line) > 74 && substr($line, 0, 1) != "#" && strstr($line, "INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES(") != FALSE)
+        $ltype = 3;
+      else if (strlen($line) > 88 && substr($line, 0, 1) != "#" && strstr($line, "INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES(") != FALSE)
+        $ltype = 4;
+
+      if ($ltype > 0) {
+        switch($ltype) {
+          case 1: $linex = substr($line, 52); break;
+          case 2: $linex = substr($line, 64); break;
+          case 3: $linex = substr($line, 65); break;
+          case 4: $linex = substr($line, 77); break;
+        }
+
+        $linex = rtrim($linex, ")");
+        $lines = explode(',', $linex);
+
+        for ($i = 0; isset($lines[$i]); $i++) {
+          $lines[$i] = ltrim($lines[$i], "'");
+          $lines[$i] = rtrim($lines[$i], "'");
+        }
+
+        $result = sql_querynb($link, "SELECT COUNT(*) FROM {$dbpre}weapons WHERE wp_type='{$lines[0]}'");
+        if (sql_num_rows($result) > 0) {
+          sql_free_result($result);
+          $qstring = "";
+          switch($ltype) {
+            case 1: $qstring = "UPDATE {$dbpre}weapons SET wp_desc='{$lines[1]}' WHERE wp_type='{$lines[0]}'"; break;
+            case 2: $qstring = "UPDATE {$dbpre}weapons SET wp_desc='{$lines[1]}',wp_weaptype='{$lines[2]}' WHERE wp_type='{$lines[0]}'"; break;
+            case 3: $qstring = "UPDATE {$dbpre}weapons SET wp_desc='{$lines[1]}',wp_secondary='{$lines[2]}' WHERE wp_type='{$lines[0]}'"; break;
+            case 4: $qstring = "UPDATE {$dbpre}weapons SET wp_desc='{$lines[1]}',wp_weaptype='{$lines[2]}',wp_secondary='{$lines[3]}' WHERE wp_type='{$lines[0]}'"; break;
+          }
+          sql_querynb($link, $qstring);
+        }
+        else {
+          sql_free_result($result);
+          $line = str_replace("%dbpre%", "$dbpre", $line);
+          sql_querynb($link, $line);
+        }
+      }
+    }
+  }
+
+  echo "Updating item descriptions....<br />\n";
+  $fname = "tables/".strtolower($dbtype)."/items.sql";
+  if (file_exists($fname)) {
+    $sqldata = file($fname);
+
+    while($row = each($sqldata)) {
+      $line = trim($row[1], "\t\n\r\0;");
+      $line = str_replace("\n", "", $line);
+
+      if (strlen($line) > 57 && substr($line, 0, 1) != "#" && strstr($line, "INSERT INTO %dbpre%items (it_type,it_desc) VALUES(") != FALSE) {
+        $linex = substr($line, 50);
+        $linex = rtrim($linex, ")");
+        $lines = explode(',', $linex);
+
+        for ($i = 0; isset($lines[$i]); $i++) {
+          $lines[$i] = ltrim($lines[$i], "'");
+          $lines[$i] = rtrim($lines[$i], "'");
+        }
+
+        $result = sql_querynb($link, "SELECT COUNT(*) FROM {$dbpre}items WHERE it_type='{$lines[0]}'");
+        if (sql_num_rows($result) > 0) {
+          sql_free_result($result);
+          sql_querynb($link, "UPDATE {$dbpre}items SET it_desc='{$lines[1]}' WHERE it_type='{$lines[0]}'");
+        }
+        else {
+          sql_free_result($result);
+          $line = str_replace("%dbpre%", "$dbpre", $line);
+          sql_querynb($link, $line);
+        }
+      }
+    }
+  }
+
+  echo "Updating version....<br />\n";
+  $result = sql_queryn($link, "UPDATE {$dbpre}config SET value='3.04' WHERE conf='Version'");
+  if (!$result) {
+    echo "<br />Error updating version.{$break}\n";
+    exit;
+  }
+
+  sql_close($link);
+  echo "<br />Database updates complete.<br />\n";
+}
+
 function update303()
 {
   global $dbtype, $dbpre, $break;
