@@ -523,11 +523,16 @@ function GetStatus($ip, $port)
       return false;
     }
     $data = substr($data, 16, -6);
-    $sdata = explode("\x00", $data);
+
+	$tempdata = explode("\x01", $data);
+    $sdata = explode("\x00", $tempdata[0]);
+    $tempdata = explode("\x02", $tempdata[1]);
+    $pdata = explode("\x00\x00", $tempdata[0]);
+    $tdata = explode("\x00\x00", $tempdata[1]);
 
     $sd = 0;
     $xmut = "";
-    while (isset($sdata[$sd])) {
+    while (isset($sdata[$sd]) && isset($sdata[$sd + 1])) {
       $ok = 1;
       $param = $sdata[$sd++];
       $val = $sdata[$sd++];
@@ -599,38 +604,40 @@ function GetStatus($ip, $port)
             $mut = "";
             $ival = intval($val);
             if ($ival & 0x0001)
-              $mut .= "Big Head, "; // UTGame.UTMutator_BigHead = 1
+              $mut .= "Kills Slow Time, "; // UTGame.UTMutator_???? = 1
             if ($ival & 0x0002)
-              $mut .= "Friendly Fire, "; // UTGame.UTMutator_FriendlyFire = 2
-            if ($ival & 0x0004)
-              $mut .= "Handicap, "; // UTGame.UTMutator_Handicap = 4
+              $mut .= "Big Head, "; // UTGame.UTMutator_BigHead = 2
             if ($ival & 0x0008)
-              $mut .= "Instagib, "; // UTGame.UTMutator_Instagib = 8
+              $mut .= "Friendly Fire, "; // UTGame.UTMutator_FriendlyFire = 8
             if ($ival & 0x0010)
-              $mut .= "Low Gravity, "; // UTGame.UTMutator_LowGrav = 16
+              $mut .= "Handicap, "; // UTGame.UTMutator_Handicap = 16
+            if ($ival & 0x0020)
+              $mut .= "Instagib, "; // UTGame.UTMutator_Instagib = 32
             if ($ival & 0x0040)
-              $mut .= "No Powerups, "; // UTGame.UTMutator_NoPowerups = 64
+              $mut .= "Low Gravity, "; // UTGame.UTMutator_LowGrav = 64
             if ($ival & 0x0080)
-              $mut .= "No Translocator, "; // UTGame.UTMutator_NoTranslocator = 128
+              $mut .= "No Super Pickups, "; // UTGame.UTMutator_NoPowerups = 128
             if ($ival & 0x0100)
-              $mut .= "Slomo, "; // UTGame.UTMutator_Slomo = 256
+              $mut .= "No Translocator, "; // UTGame.UTMutator_NoTranslocator = 256
+            if ($ival & 0x0200)
+              $mut .= "Slo Mo, "; // UTGame.UTMutator_Slomo = 512
             if ($ival & 0x0400)
               $mut .= "Speed Freak, "; // UTGame.UTMutator_SpeedFreak = 1024
             if ($ival & 0x0800)
               $mut .= "Super Berserk, "; // UTGame.UTMutator_SuperBerserk = 2048
-            if ($ival & 0x2000)
+            if ($ival & 0x1000)
               $mut .= "Weapon Replacement, "; // UTGame.UTMutator_WeaponReplacement = 8192
-            if ($ival & 0x4000)
+            if ($ival & 0x2000)
               $mut .= "Weapons Respawn, "; // UTGame.UTMutator_WeaponsRespawn = 16384
             if ($mut == "")
-              $sq_server["mutator"] = "None";
+              $sq_server["mutator"] = "";
             else
               $sq_server["mutator"] = substr($mut, 0, -2);
             break;
           }
           case "p1073741828":
           {
-            $xmut = ", ";
+            $xmut = "";
           	for ($i = 0; $i < strlen($val); $i++)
           	{
           	  if (ord($val[$i]) == 28)
@@ -645,10 +652,89 @@ function GetStatus($ip, $port)
         }
       }
     }
-    $sq_server["mutator"] .= $xmut;
+
+    if ($sq_server["mutator"] == "" && $xmut == "")
+      $sq_server["mutator"] = "None";
+    else if ($sq_server["mutator"] != "" && $xmut != "")
+      $sq_server["mutator"] .= ", ";
+    if ($xmut != "")
+      $sq_server["mutator"] .= $xmut;
+
     $i = strpos($sq_server["mapname"], '-');
     if (strlen($sq_server["mapname"]) > $i + 2)
       $sq_server["mapname"] = substr($sq_server["mapname"], 0, $i + 2).strtolower(substr($sq_server["mapname"], $i + 2));
+
+    // Players
+    $sd = 0;
+    while (isset($pdata[$sd]) && isset($pdata[$sd + 1])) {
+      $param = $pdata[$sd++];
+      $val = $pdata[$sd++];
+      if (strlen($val) > 0 && ord($val) != 0x00) {
+        switch ($param) {
+          case "player_":
+            $tempdata = explode("\x00", $val);
+            $i = 0;
+            foreach ($tempdata as $tempd)
+              $sq_player[$i++]["player"] = $tempd;
+            break;
+          case "score_":
+            $tempdata = explode("\x00", $val);
+            $i = 0;
+            foreach ($tempdata as $tempd)
+              $sq_player[$i++]["score"] = $tempd;
+            break;
+          case "ping_":
+            $tempdata = explode("\x00", $val);
+            $i = 0;
+            foreach ($tempdata as $tempd)
+              $sq_player[$i++]["ping"] = $tempd;
+            break;
+          case "team_": // This doesn't appear to tell who is on what team.
+            $tempdata = explode("\x00", $val);
+            $i = 0;
+            foreach ($tempdata as $tempd)
+              $sq_player[$i++]["team"] = 0; // Lacking proper info in UT3
+            break;
+          case "deaths_":
+            $tempdata = explode("\x00", $val);
+            $i = 0;
+            foreach ($tempdata as $tempd)
+              $sq_player[$i++]["deaths"] = $tempd;
+            break;
+          case "pid_":
+            break;
+        }
+      }
+    }
+
+    // Teams
+    $sd = 0;
+    while (isset($tdata[$sd]) && isset($tdata[$sd + 1])) {
+      $param = $tdata[$sd++];
+      $val = $tdata[$sd++];
+      if (strlen($val) > 0 && ord($val) != 0x00) {
+        switch ($param) {
+          case "team_t":
+            break;
+          case "score_t":
+            $tempdata = explode("\x00", $val);
+            $i = 0;
+            foreach ($tempdata as $tempd) {
+              switch($i) {
+                case 0: $sq_team[$i]["team"] = "Red"; break;
+                case 1: $sq_team[$i]["team"] = "Blue"; break;
+                case 2: $sq_team[$i]["team"] = "Color3"; break;
+                case 3: $sq_team[$i]["team"] = "Color4"; break;
+                default: $sq_team[$i]["team"] = "TeamX";
+              }
+              $sq_team[$i]["size"] = 0; // Team info incomplete in UT3 query
+              $sq_team[$i++]["score"] = $tempd;
+              $teams = -1; // Team info incomplete in UT3 query
+            }
+            break;
+        }
+      }
+    }
   }
 
   fclose($fs);
@@ -768,12 +854,10 @@ EOF;
   echo <<<EOF
     </td>
   </tr>
-  <tr>
-    <td>
 
 EOF;
 
-  if (isset($sq_team[1])) {
+  if (isset($sq_team[1]) && $teams >= 0) {
     if (isset($sq_server["minplayers"]))
       $ncol = 5;
     else
@@ -788,11 +872,15 @@ EOF;
             <b>{$sq_team[0]['team']} Team: &nbsp;&nbsp;Players: {$sq_team[0]['size']} &nbsp;&nbsp;Score: {$sq_team[0]['score']}</b>
           </td>
         </tr>
+        <tr>
+          <td>
 
 EOF;
 
     DisplayPlayers(1);
     echo <<<EOF
+          </td>
+        </tr>
       </table>
     </td>
   </tr>
@@ -804,13 +892,15 @@ EOF;
             <b>{$sq_team[1]['team']} Team: &nbsp;&nbsp;Players: {$sq_team[1]['size']} &nbsp;&nbsp;Score: {$sq_team[1]['score']}</b>
           </td>
         </tr>
+        <tr>
+          <td>
 
 EOF;
     DisplayPlayers(2);
     echo <<<EOF
+          </td>
+        </tr>
       </table>
-    </td>
-  </tr>
 
 EOF;
   }
@@ -850,6 +940,26 @@ EOF;
 
 EOF;
   }
+  else if ($teams < 0) {
+    echo <<<EOF
+  <tr>
+    <td colspan="5">
+      <table class="status" cellspacing="0" cellpadding="1" width="100%">
+        <tr>
+          <td class="redteambar" align="center" width="50%">
+            <b>Red Team Score: {$sq_team[0]['score']}</b>
+          </td>
+          <td style="font-size: 1pt">&nbsp;</td>
+          <td class="blueteambar" align="center" width="50%">
+            <b>Blue Team Score: {$sq_team[1]['score']}</b>
+          </td>
+        </tr>
+      </table>
+
+EOF;
+
+    DisplayPlayers(0);
+  }
   else
     DisplayPlayers(0);
 
@@ -900,6 +1010,8 @@ function DisplayPlayers($teamnum)
       	  $name[] = $plr["player"];
           $score[] = $plr["score"];
           $ping[] = $plr["ping"];
+          if (isset($plr["team"]))
+            $team[] = $plr["team"];
           if ($score[$numplr] == 0xffff)
             $score[$numplr] = 0;
           $numplr++;
@@ -913,31 +1025,40 @@ function DisplayPlayers($teamnum)
     for ($i = 0; $i < $numplr; $i++) {
       if (!$header) {
     echo <<<EOF
-      <table class="status" cellspacing="0" cellpadding="1" width="100%">
-        <tr>
-          <td class="statustitle" align="center" colspan="3">
-            <b>Players</b>
-          </td>
-        </tr>
-        <tr>
-          <td width="200"><b>Name</b></td>
-          <td width="50"><b>Score</b></td>
-          <td width="50"><b>Ping</b></td>
-        </tr>
+      <tr>
+        <td>
+          <table class="status" cellspacing="0" cellpadding="1" width="100%">
+            <tr>
+              <td class="statustitle" align="center" colspan="3">
+                <b>Players</b>
+              </td>
+            </tr>
+            <tr>
+              <td width="200"><b>Name</b></td>
+              <td width="50"><b>Score</b></td>
+              <td width="50"><b>Ping</b></td>
+            </tr>
 EOF;
           $header = 1;
       }
 
-      echo <<<EOF
-        <tr>
-          <td>$name[$i]</td>
-          <td>$score[$i]</td>
-          <td>$ping[$i]</td>
-        </tr>
+      if (isset($name[$i]) && (!$teamnum || (isset($team[$i]) && $team[$i] == $teamnum - 1))) {
+        echo <<<EOF
+            <tr>
+              <td>{$name[$i]}</td>
+              <td>{$score[$i]}</td>
+              <td>{$ping[$i]}</td>
+            </tr>
 EOF;
+      }
     }
     if ($header)
-      echo "      </table>\n";
+      echo <<<EOF
+          </table>
+        </td>
+      </tr>
+
+EOF;
   }
   else {
     if ($teamnum)
