@@ -18,7 +18,7 @@
         </tr>
       </table>
     </td>
-    <td width="350" align="center"><img src="mapimages/$mapimage" width="256" height="192" border="1" alt="Map Image"></td>
+    <td width="350" align="center"><img src="mapimages/$mapimage" width="256" height="192" border="1" alt="Map Image" /></td>
   </tr>
 </table>
 
